@@ -14,6 +14,8 @@ class TestCommandsOnValueTypes < Minitest::Test
 
     assert_equal ["bar", "baz", "foo"], r.keys("*").sort
 
+    assert_equal 0, r.del("")
+
     assert_equal 1, r.del("foo")
 
     assert_equal ["bar", "baz"], r.keys("*").sort
@@ -30,6 +32,8 @@ class TestCommandsOnValueTypes < Minitest::Test
 
     assert_equal ["bar", "baz", "foo"], r.keys("*").sort
 
+    assert_equal 0, r.del([])
+
     assert_equal 1, r.del(["foo"])
 
     assert_equal ["bar", "baz"], r.keys("*").sort
