@@ -165,6 +165,26 @@ module Helper
     def version
       Version.new(redis.info['redis_version'])
     end
+
+    def with_acl
+      admin = _new_client
+      admin.acl('SETUSER', 'johndoe', 'on',
+                '+ping', '+select', '+command', '+cluster|slots', '+cluster|nodes',
+                '>mysecret')
+      yield('johndoe', 'mysecret')
+    ensure
+      admin.acl('DELUSER', 'johndoe')
+      admin.close
+    end
+
+    def with_default_user_password
+      admin = _new_client
+      admin.acl('SETUSER', 'default', '>mysecret')
+      yield('default', 'mysecret')
+    ensure
+      admin.acl('SETUSER', 'default', 'nopass')
+      admin.close
+    end
   end
 
   module Client
