@@ -45,6 +45,35 @@ module Lint
         # Incompatible options combination
         assert_raises(Redis::CommandError) { r.zadd("foo", 1, "s1", xx: true, nx: true) }
       end
+
+      target_version "6.2" do
+        # LT option
+        r.zadd("foo", 2, "s1")
+
+        r.zadd("foo", 3, "s1", lt: true)
+        assert_equal 2.0, r.zscore("foo", "s1")
+
+        r.zadd("foo", 1, "s1", lt: true)
+        assert_equal 1.0, r.zscore("foo", "s1")
+
+        assert_equal true, r.zadd("foo", 3, "s2", lt: true) # adds new member
+        r.del "foo"
+
+        # GT option
+        r.zadd("foo", 2, "s1")
+
+        r.zadd("foo", 1, "s1", gt: true)
+        assert_equal 2.0, r.zscore("foo", "s1")
+
+        r.zadd("foo", 3, "s1", gt: true)
+        assert_equal 3.0, r.zscore("foo", "s1")
+
+        assert_equal true, r.zadd("foo", 1, "s2", gt: true) # adds new member
+        r.del "foo"
+
+        # Incompatible options combination
+        assert_raises(Redis::CommandError) { r.zadd("foo", 1, "s1", nx: true, gt: true) }
+      end
     end
 
     def test_variadic_zadd
@@ -109,6 +138,28 @@ module Lint
         # Incompatible options combination
         assert_raises(Redis::CommandError) { r.zadd("foo", [1, "s1"], xx: true, nx: true) }
       end
+
+      target_version "6.2" do
+        # LT option
+        r.zadd("foo", 2, "s1")
+
+        assert_equal 1, r.zadd("foo", [3, "s1", 2, "s2"], lt: true, ch: true)
+        assert_equal 2.0, r.zscore("foo", "s1")
+
+        assert_equal 1, r.zadd("foo", [1, "s1"], lt: true, ch: true)
+
+        r.del "foo"
+
+        # GT option
+        r.zadd("foo", 2, "s1")
+
+        assert_equal 1, r.zadd("foo", [1, "s1", 2, "s2"], gt: true, ch: true)
+        assert_equal 2.0, r.zscore("foo", "s1")
+
+        assert_equal 1, r.zadd("foo", [3, "s1"], gt: true, ch: true)
+
+        r.del "foo"
+      end
     end
 
     def test_zrem
@@ -293,6 +344,48 @@ module Lint
       assert_equal(+Float::INFINITY, r.zscore("bar", "s2"))
     end
 
+    def test_zmscore
+      target_version("6.2") do
+        r.zadd "foo", 1, "s1"
+
+        assert_equal [1.0], r.zmscore("foo", "s1")
+        assert_equal [nil], r.zmscore("foo", "s2")
+
+        r.zadd "foo", "-inf", "s2"
+        r.zadd "foo", "+inf", "s3"
+        assert_equal [1.0, nil], r.zmscore("foo", "s1", "s4")
+        assert_equal [-Float::INFINITY, +Float::INFINITY], r.zmscore("foo", "s2", "s3")
+      end
+    end
+
+    def test_zrandmember
+      target_version("6.2") do
+        assert_nil r.zrandmember("foo")
+
+        r.zadd "foo", 1.0, "s1"
+        r.zrem "foo", "s1"
+        assert_nil r.zrandmember("foo")
+        assert_equal [], r.zrandmember("foo", 1)
+
+        r.zadd "foo", 1.0, "s1"
+        r.zadd "foo", 2.0, "s2"
+        r.zadd "foo", 3.0, "s3"
+
+        3.times do
+          assert ["s1", "s2", "s3"].include?(r.zrandmember("foo"))
+        end
+
+        assert_equal 2, r.zrandmember("foo", 2).size
+        assert_equal 3, r.zrandmember("foo", 4).size
+        assert_equal 5, r.zrandmember("foo", -5).size
+
+        r.zrandmember("foo", 2, with_scores: true).each do |(member, score)|
+          assert ["s1", "s2", "s3"].include?(member)
+          assert_instance_of Float, score
+        end
+      end
+    end
+
     def test_zremrangebyrank
       r.zadd "foo", 10, "s1"
       r.zadd "foo", 20, "s2"
@@ -432,6 +525,55 @@ module Lint
       assert_equal 5, r.zunionstore('{1}baz', %w[{1}foo {1}bar])
     end
 
+    def test_zinter
+      target_version("6.2") do
+        r.zadd 'foo', 1, 's1'
+        r.zadd 'bar', 2, 's1'
+        r.zadd 'foo', 3, 's3'
+        r.zadd 'bar', 4, 's4'
+
+        assert_equal ['s1'], r.zinter('foo', 'bar')
+        assert_equal [['s1', 3.0]], r.zinter('foo', 'bar', with_scores: true)
+      end
+    end
+
+    def test_zinter_with_weights
+      target_version("6.2") do
+        r.zadd 'foo', 1, 's1'
+        r.zadd 'foo', 2, 's2'
+        r.zadd 'foo', 3, 's3'
+        r.zadd 'bar', 20, 's2'
+        r.zadd 'bar', 30, 's3'
+        r.zadd 'bar', 40, 's4'
+
+        assert_equal %w[s2 s3], r.zinter('foo', 'bar')
+        assert_equal [['s2', 22.0], ['s3', 33.0]], r.zinter('foo', 'bar', with_scores: true)
+
+        assert_equal %w[s2 s3], r.zinter('foo', 'bar', weights: [10, 1])
+        assert_equal [['s2', 40.0], ['s3', 60.0]], r.zinter('foo', 'bar', weights: [10, 1], with_scores: true)
+      end
+    end
+
+    def test_zinter_with_aggregate
+      target_version("6.2") do
+        r.zadd 'foo', 1, 's1'
+        r.zadd 'foo', 2, 's2'
+        r.zadd 'foo', 3, 's3'
+        r.zadd 'bar', 20, 's2'
+        r.zadd 'bar', 30, 's3'
+        r.zadd 'bar', 40, 's4'
+
+        assert_equal %w[s2 s3], r.zinter('foo', 'bar')
+        assert_equal [['s2', 22.0], ['s3', 33.0]], r.zinter('foo', 'bar', with_scores: true)
+
+        assert_equal %w[s2 s3], r.zinter('foo', 'bar', aggregate: :min)
+        assert_equal [['s2', 2.0], ['s3', 3.0]], r.zinter('foo', 'bar', aggregate: :min, with_scores: true)
+
+        assert_equal %w[s2 s3], r.zinter('foo', 'bar', aggregate: :max)
+        assert_equal [['s2', 20.0], ['s3', 30.0]], r.zinter('foo', 'bar', aggregate: :max, with_scores: true)
+      end
+    end
+
     def test_zinterstore
       r.zadd 'foo', 1, 's1'
       r.zadd 'bar', 2, 's1'
