@@ -3,21 +3,21 @@
 module Lint
   module ValueTypes
     def test_exists
-      assert_equal false, r.exists("foo")
-
-      r.set("foo", "s1")
-
-      assert_equal true,  r.exists("foo")
-    end
-
-    def test_exists_integer
-      previous_exists_returns_integer = Redis.exists_returns_integer
-      Redis.exists_returns_integer = true
       assert_equal 0, r.exists("foo")
 
       r.set("foo", "s1")
 
-      assert_equal 1,  r.exists("foo")
+      assert_equal 1, r.exists("foo")
+    end
+
+    def test_exists_integer
+      previous_exists_returns_integer = Redis.exists_returns_integer
+      Redis.exists_returns_integer = false
+      assert_equal false, r.exists("foo")
+
+      r.set("foo", "s1")
+
+      assert_equal true, r.exists("foo")
     ensure
       Redis.exists_returns_integer = previous_exists_returns_integer
     end
